summaryrefslogtreecommitdiffstats
path: root/cervisia/entry_status.h
diff options
context:
space:
mode:
Diffstat (limited to 'cervisia/entry_status.h')
-rw-r--r--cervisia/entry_status.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/cervisia/entry_status.h b/cervisia/entry_status.h
index aa964735..b1d6cf6f 100644
--- a/cervisia/entry_status.h
+++ b/cervisia/entry_status.h
@@ -31,7 +31,7 @@ namespace Cervisia
/**
* All stati a an entry could have.
*/
-enum EntryStatus
+enum EntrytqStatus
{
LocallyModified,
LocallyAdded,
@@ -51,11 +51,11 @@ enum EntryStatus
/**
* The entry status as translated string.
*
* @param entryStatus The entry status to translate.
*
* @return The translated string.
*/
-TQString toString(EntryStatus entryStatus);
+TQString toString(EntrytqStatus entrytqStatus);
} // namespace Cervisia
@@ -51,11 +51,11 @@ enum EntryStatus
* The entry status as translated string.
*
- * @param entryStatus The entry status to translate.
+ * @param entrytqStatus The entry status to translate.
*
* @return The translated string.